@@ -75,6 +75,7 @@ void init()
 
 	data_handle = -1;  /* initialize to empty handle */
 	data_source = ESD;
+	comedi_window_open = TRUE;  /* open comedi control window */
 
 	refresh_rate = 34;	/* 34 frames per sec */
 	left_amplitude = 127.0/32768.0; /* Scaler for something */
@@ -169,7 +170,7 @@ void read_config(void)
 		cfg_read_int(cfgfile, "Global", "major_ver", &major_ver);
 		cfg_read_int(cfgfile, "Global", "minor_ver", &minor_ver);
 		cfg_read_int(cfgfile, "Global", "micro_ver", &micro_ver);
-		if (major_ver == 0)
+		if ((major_ver == 1) && (minor_ver == 8))
 		{
 			printf("Config file structure changed. using defaults. \nClosing eXtace will save your NEW settings.\n");
 			cfg_free(cfgfile);
@@ -211,6 +212,8 @@ void read_config(void)
 		  if(cfg_read_int(cfgfile, "Global", "data_source", &i))
 		  data_source=i;
 		}
+		cfg_read_int(cfgfile, "Global", "comedi_window_open", 
+			     &comedi_window_open);
 		cfg_read_int(cfgfile, "Global", "decimation_factor", &decimation_factor);
 		cfg_read_int(cfgfile, "Global", "fft_signal_source", &fft_signal_source);
 		cfg_read_int(cfgfile, "Global", "refresh_rate", &refresh_rate);
@@ -293,6 +296,7 @@ void save_config(GtkWidget *widget)
 		cfg_write_string(cfgfile, "Global", "last_colormap",g_strconcat(g_get_home_dir(),"/.eXtace/ColorMaps/","Default",NULL));
 	cfg_write_int(cfgfile, "Global", "mode", mode);
 	cfg_write_int(cfgfile, "Global", "data_source", data_source);
+	cfg_write_int(cfgfile, "Global", "comedi_window_open", comedi_window_open);
 	cfg_write_int(cfgfile, "Global", "decimation_factor", decimation_factor);
 	cfg_write_int(cfgfile, "Global", "fft_signal_source", fft_signal_source);
 	cfg_write_int(cfgfile, "Global", "refresh_rate", refresh_rate);
@@ -506,7 +510,7 @@ void mem_dealloc()
 	//	free(Color_map.locations);
 
 	if (plan)
-		rfftw_destroy_plan(plan);
+		fftw_destroy_plan(plan);
 	convolve_close(l_state); 
 	convolve_close(r_state); 
 }
@@ -545,8 +549,12 @@ void reinit_extace(int new_nsamp)
 	/* only start if it has been stopped above */
 	if(data_handle != -1 && (data_handle=open_datasource(data_source)) >= 0)
 	  {
-	    input_thread_starter(data_handle);
-	    draw_start();
+		  plan = fftw_create_plan(nsamp, FFTW_FORWARD, FFTW_ESTIMATE);
+		  input_thread_starter(data_handle);
+		  ring_rate_changed(); /* Fix all gui controls that depend on
+					* ring_rate (adjustments and such
+					*/
+		  draw_start();
 	  }
 }
 
