@@ -4,7 +4,6 @@
  * /GDK/GNOME sound (esd) system output display program
  * 
  * Based on the original extace written by The Rasterman and Michael Fulbright
- *  
  * 
  * This software comes under the GPL (GNU Public License)
  * You may freely copy,distribute etc. this as long as the source code
@@ -248,11 +247,20 @@ int main(int argc, char **argv)
 		update_pointer();
 	}
 
-	if ((data_handle=open_datasource(data_source)) != -1)
-	  {
-	    input_thread_starter(data_handle);
-	    draw_start();
-	  }
+	if ((data_handle=open_datasource(data_source)) >= 0)
+	{
+		plan = rfftw_create_plan(nsamp, FFTW_FORWARD, FFTW_ESTIMATE);
+		ring_rate_changed(); /* Fix all gui controls that depend on
+				      * ring_rate (adjustments and such)
+				      */
+		input_thread_starter(data_handle);
+		draw_start();
+	}
+	/* This will open comedi window on startup when approprate */
+	if(data_source == COMEDI)
+		gtk_toggle_button_set_active(
+			GTK_TOGGLE_BUTTON(comedi_button), 
+			comedi_window_open);
 	if (mode == STARS)/* gotta emit it by hand due to config file */
 		gtk_signal_emit_by_name(GTK_OBJECT(about_button),"clicked");
 	ready = 1;		/* All set */
