@@ -34,6 +34,8 @@ extern gint scope_sync_source;
 int setup_options()
 {
 
+	gint i;
+	char str[16];
 	GtkWidget *options;
 	GtkWidget *vbox;
 	GtkWidget *eventbox;
@@ -88,7 +90,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)REFRESH_RATE);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(REFRESH_RATE));
 	sep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(vbox),sep,TRUE, TRUE, 0);
 
@@ -98,78 +101,21 @@ int setup_options()
 
 	hbox = gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,TRUE,TRUE,0);
+	group=NULL;
 
-	button = gtk_radio_button_new_with_label(NULL, "1 (None)");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)1);
-        if (decimation_factor == 1)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "2");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)2);
-        if (decimation_factor == 2)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "3");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)3);
-        if (decimation_factor == 3)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "4");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)4);
-        if (decimation_factor == 4)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "5");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)5);
-        if (decimation_factor == 5)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "6");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)6);
-        if (decimation_factor == 6)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "7");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)7);
-        if (decimation_factor == 7)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
-        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-        button = gtk_radio_button_new_with_label(group, "8");
-        gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
-        gtk_signal_connect(GTK_OBJECT (button), "clicked",
-                        GTK_SIGNAL_FUNC (set_decimation_factor), \
-			(gpointer)8);
-        if (decimation_factor == 8)
-                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-
+	for(i=1; i<=8; i++){
+		if(i==1)
+			sprintf(str,"1 (None)");
+		else
+			sprintf(str,"%i",i);
+		button = gtk_radio_button_new_with_label(group,str);
+		gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
+		gtk_signal_connect(GTK_OBJECT (button), "clicked",
+				   GTK_SIGNAL_FUNC (set_decimation_factor), \
+				   GINT_TO_POINTER(i));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), decimation_factor == i);
+		group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+	}
 
 	sep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(vbox),sep,TRUE, TRUE, 0);
@@ -177,7 +123,8 @@ int setup_options()
 	button = gtk_toggle_button_new_with_label("Pause Display");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)PAUSE_DISP);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(PAUSE_DISP));
 
 	frame = gtk_frame_new("Sound Source");
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
@@ -188,40 +135,84 @@ int setup_options()
 
 	label = gtk_label_new("Choose Sound Source ");
 	gtk_box_pack_start(GTK_BOX(sub_vbox),label,TRUE,TRUE,0);
+	group = NULL;
 
 	/* 
 	   Do gtk_toggle_button_set_active() before gtk_signal_connect()
 	   so set_data_source is not run on initialization.
 	*/
 
-	button = gtk_radio_button_new_with_label(NULL, "Use Esound");
+#ifdef HAVE_ESD
+	button = gtk_radio_button_new_with_label(group, "Use Esound");
+        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	gtk_box_pack_start(GTK_BOX(sub_vbox),button,TRUE,TRUE,0);
 	if (data_source == ESD)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button),"toggled",
-			GTK_SIGNAL_FUNC(set_data_source),(gpointer)ESD);
+			   GTK_SIGNAL_FUNC(set_data_source),
+			   GINT_TO_POINTER(ESD));
+#endif
 
+#if defined(HAVE_OSS) && defined(EXPERIMENTAL)
+	button = gtk_radio_button_new_with_label(group, "Use OSS (experimental)");
         group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-	button = gtk_radio_button_new_with_label(group, "Use COMEDI");
 	gtk_box_pack_start(GTK_BOX(sub_vbox),button,TRUE,TRUE,0);
+	if (data_source == OSS)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+	gtk_signal_connect(GTK_OBJECT(button),"toggled",
+			   GTK_SIGNAL_FUNC(set_data_source),
+			   GINT_TO_POINTER(OSS));
+#endif
+
+#if defined(HAVE_ALSA) && defined(EXPERIMENTAL)
+	button = gtk_radio_button_new_with_label(group, "Use ALSA (experimental)");
+        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+	gtk_box_pack_start(GTK_BOX(sub_vbox),button,TRUE,TRUE,0);
+	if (data_source == ALSA)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+	gtk_signal_connect(GTK_OBJECT(button),"toggled",
+			   GTK_SIGNAL_FUNC(set_data_source),
+			   GINT_TO_POINTER(ALSA));
+#endif
+
+#ifdef HAVE_COMEDI
+	hbox = gtk_hbox_new(FALSE,0);
+	button = gtk_radio_button_new_with_label(group, "Use COMEDI");
+        group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
+	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	if (data_source == COMEDI)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button),"toggled",
-			GTK_SIGNAL_FUNC(set_data_source),(gpointer)COMEDI);
+			   GTK_SIGNAL_FUNC(set_data_source),
+			   GINT_TO_POINTER(COMEDI));
+	if(comedi_window_open)
+		comedi_button = gtk_toggle_button_new_with_label("Close control window");
+	else
+		comedi_button = gtk_toggle_button_new_with_label("Open control window");
+	gtk_widget_set_sensitive(comedi_button,data_source == COMEDI);
+	gtk_box_pack_start(GTK_BOX(hbox),comedi_button,TRUE,TRUE,0);
+	gtk_signal_connect(GTK_OBJECT(comedi_button),"toggled",
+			GTK_SIGNAL_FUNC(comedi_control_window_toggle),NULL);
+	gtk_container_add(GTK_CONTAINER(sub_vbox), hbox);
+#else
+	comedi_button = NULL;
+#endif
 
+#if defined(HAVE_ARTS) && defined(DEBUG)
+	button = gtk_radio_button_new_with_label(group, "Use ARTS (experimental)");
         group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
-	button = gtk_radio_button_new_with_label(group, "Use ARTS");
 	gtk_box_pack_start(GTK_BOX(sub_vbox),button,TRUE,TRUE,0);
 	if (data_source == ARTS)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button),"toggled",
-			GTK_SIGNAL_FUNC(set_data_source),(gpointer)ARTS);
+			   GTK_SIGNAL_FUNC(set_data_source),
+			   GINT_TO_POINTER(ARTS));
+#endif
 
 	gtk_widget_show_all(vbox);
 	
 	/*  END of General Options Tab (Options Panel) */
 
-
 	/*  BEGINNING of Low Res. FFT Options Tab (Options Panel) */
 	box = gtk_hbox_new(FALSE,0);
 
@@ -245,7 +236,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)BANDS);
+			    GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(BANDS));
 
 	label = gtk_label_new("Bar Decay Speed");
 	gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,0);
@@ -257,7 +249,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)BAR_DECAY);
+			GTK_SIGNAL_FUNC (slider_changed),
+			    GINT_TO_POINTER(BAR_DECAY));
 
 	label = gtk_label_new("Peak Hold Time");
 	gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,0);
@@ -269,7 +262,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)PEAK_HOLD);
+			GTK_SIGNAL_FUNC (slider_changed),
+			    GINT_TO_POINTER(PEAK_HOLD));
 
 
 	label = gtk_label_new("Peak Decay Speed");
@@ -283,7 +277,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)PEAK_DECAY);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(PEAK_DECAY));
 
 	sep = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(vbox),sep,TRUE, TRUE, 0);
@@ -294,19 +289,22 @@ int setup_options()
 	button = gtk_toggle_button_new_with_label("Leading Edge Shown");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)LEADING_EDGE);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(LEADING_EDGE));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), show_leader);
 
 	button = gtk_toggle_button_new_with_label("Bar Decay Disabled");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)USE_BAR_DECAY);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(USE_BAR_DECAY));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), bar_decay);
 
 	button = gtk_toggle_button_new_with_label("Peak Decay Disabled");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)USE_PEAK_DECAY);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(USE_PEAK_DECAY));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), peak_decay);
 
 	hbox1 = gtk_hbox_new(TRUE,0);
@@ -315,20 +313,23 @@ int setup_options()
 	button = gtk_toggle_button_new_with_label("Invert Landform Y-axis");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)LANDFLIP);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(LANDFLIP));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),landflip);
 
 	button = gtk_toggle_button_new_with_label("Smooth 3D Landform");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)OUTLINED);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(OUTLINED));
 	if (outlined == TRUE)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),TRUE);
 
 	button = gtk_toggle_button_new_with_label("Landform Perspective Tilt Disabled");
 	gtk_box_pack_start(GTK_BOX(hbox1),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)LAND_PERS_TILT);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(LAND_PERS_TILT));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), landtilt);
 
 
@@ -338,7 +339,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(NULL, "Linear Frequency Axis");
 	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (fft_set_axis_type), (gpointer)LINEAR);
+			GTK_SIGNAL_FUNC (fft_set_axis_type), 
+			   GINT_TO_POINTER(LINEAR));
 	if (axis_type == LINEAR)
 	{
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
@@ -348,7 +350,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(group, "Logarithmic Frequency Axis");
 	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (fft_set_axis_type), (gpointer)LOG);
+			GTK_SIGNAL_FUNC (fft_set_axis_type), 
+			   GINT_TO_POINTER(LOG));
 	if (axis_type == LOG)
 	{
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
@@ -382,7 +385,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(NULL, "Gradient Scope");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (scope_mode), (gpointer)GRAD_SCOPE);
+			GTK_SIGNAL_FUNC (scope_mode),
+			   GINT_TO_POINTER(GRAD_SCOPE));
 	if (scope_sub_mode == GRAD_SCOPE)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -390,7 +394,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(group, "Dot Scope");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (scope_mode), (gpointer)DOT_SCOPE);
+			GTK_SIGNAL_FUNC (scope_mode), 
+			   GINT_TO_POINTER(DOT_SCOPE));
 	if (scope_sub_mode == DOT_SCOPE)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -398,7 +403,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(group, "Line Scope");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (scope_mode), (gpointer)LINE_SCOPE);
+			GTK_SIGNAL_FUNC (scope_mode), 
+			   GINT_TO_POINTER(LINE_SCOPE));
 	if (scope_sub_mode == LINE_SCOPE)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -412,13 +418,15 @@ int setup_options()
 	button = gtk_toggle_button_new_with_label("Trace Stabilizer Disabled");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)STABILIZED);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(STABILIZED));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), stabilized);
 
 	button = gtk_toggle_button_new_with_label("Scope Graticule Disabled");
 	gtk_box_pack_start(GTK_BOX(vbox),button,TRUE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)GRATICULE);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(GRATICULE));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), show_graticule);
 
 	frame = gtk_frame_new("Sync/Trigger Controls");
@@ -432,7 +440,7 @@ int setup_options()
 	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (scope_sync_source_set), 
-			(gpointer)SYNC_LEFT);
+			GINT_TO_POINTER(SYNC_LEFT));
 	if (scope_sync_source == SYNC_LEFT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -441,7 +449,7 @@ int setup_options()
 	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
 			GTK_SIGNAL_FUNC (scope_sync_source_set), 
-			(gpointer)SYNC_RIGHT);
+			GINT_TO_POINTER(SYNC_RIGHT));
 	if (scope_sync_source == SYNC_RIGHT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -449,8 +457,8 @@ int setup_options()
 	button = gtk_radio_button_new_with_label(group, "Sync Independently");
 	gtk_box_pack_start(GTK_BOX(hbox),button,TRUE,TRUE,0);
 	gtk_signal_connect(GTK_OBJECT (button), "clicked",
-			GTK_SIGNAL_FUNC (scope_sync_source_set), 
-			(gpointer)SYNC_INDEP);
+			   GTK_SIGNAL_FUNC (scope_sync_source_set), 
+			   GINT_TO_POINTER(SYNC_INDEP));
 	if (scope_sync_source == SYNC_INDEP)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
 
@@ -501,7 +509,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (lf_adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)LOW_LIMIT);
+			    GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(LOW_LIMIT));
 
 
 	/* High Frequency Limit slider */
@@ -515,7 +524,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (hf_adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)HIGH_LIMIT);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(HIGH_LIMIT));
 
 	frame = gtk_frame_new("High Resolution FFT Display Options");
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
@@ -527,13 +537,15 @@ int setup_options()
 	button = gtk_toggle_button_new_with_label("Invert Spike Y-axis");
 	gtk_box_pack_start(GTK_BOX(hbox),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)SPIKEFLIP);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(SPIKEFLIP));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button),spikeflip);
 
 	button = gtk_toggle_button_new_with_label("Spikes Perspective Tilt Disabled");
 	gtk_box_pack_start(GTK_BOX(hbox),button,FALSE,TRUE,0);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (button_handle), (gpointer)SPIKE_PERS_TILT);
+			GTK_SIGNAL_FUNC (button_handle), 
+			    GINT_TO_POINTER(SPIKE_PERS_TILT));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), spiketilt);
 
 
@@ -558,7 +570,8 @@ int setup_options()
 	if(window_func == HAMMING)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)HAMMING);
+			    GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(HAMMING));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Hanning");
@@ -566,7 +579,8 @@ int setup_options()
 	if(window_func == HANNING)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)HANNING);
+			GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(HANNING));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Blackman");
@@ -574,7 +588,8 @@ int setup_options()
 	if(window_func == BLACKMAN)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)BLACKMAN);
+			    GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(BLACKMAN));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Blackman-Harris");
@@ -582,7 +597,8 @@ int setup_options()
 	if(window_func == BLACKMAN_HARRIS)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)BLACKMAN_HARRIS);
+			GTK_SIGNAL_FUNC (setup_datawindow),
+			    GINT_TO_POINTER(BLACKMAN_HARRIS));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Gaussian");
@@ -590,7 +606,8 @@ int setup_options()
 	if(window_func == GAUSSIAN)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)GAUSSIAN);
+			GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(GAUSSIAN));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Welch");
@@ -598,7 +615,8 @@ int setup_options()
 	if(window_func == WELCH)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)WELCH);
+			GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(WELCH));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Parzen");
@@ -606,7 +624,8 @@ int setup_options()
 	if(window_func == PARZEN)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)PARZEN);
+			GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(PARZEN));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Rectangular");
@@ -614,7 +633,8 @@ int setup_options()
 	if(window_func == RECTANGULAR)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "pressed",
-			GTK_SIGNAL_FUNC (setup_datawindow), (gpointer)RECTANGULAR);
+			GTK_SIGNAL_FUNC (setup_datawindow), 
+			    GINT_TO_POINTER(RECTANGULAR));
 
 	vbox1 = gtk_vbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(hbox),vbox1,TRUE,TRUE,0);
@@ -633,7 +653,8 @@ int setup_options()
 	if(win_width == FULL)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_window_width), (gpointer)FULL);
+			GTK_SIGNAL_FUNC (set_window_width), 
+			    GINT_TO_POINTER(FULL));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Half Width");
@@ -641,7 +662,8 @@ int setup_options()
 	if(win_width == HALF)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_window_width), (gpointer)HALF);
+			GTK_SIGNAL_FUNC (set_window_width), 
+			    GINT_TO_POINTER(HALF));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Quarter Width");
@@ -649,7 +671,8 @@ int setup_options()
 	if(win_width == QUARTER)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_window_width), (gpointer)QUARTER);
+			GTK_SIGNAL_FUNC (set_window_width), 
+			    GINT_TO_POINTER(QUARTER));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Eighth Width");
@@ -657,7 +680,8 @@ int setup_options()
 	if(win_width == EIGHTH)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_window_width), (gpointer)EIGHTH);
+			GTK_SIGNAL_FUNC (set_window_width), 
+			    GINT_TO_POINTER(EIGHTH));
 
 
 
@@ -676,7 +700,8 @@ int setup_options()
 	if(fft_signal_source == LEFT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_data_to_display), (gpointer)LEFT);
+			GTK_SIGNAL_FUNC (set_fft_data_to_display), 
+			    GINT_TO_POINTER(LEFT));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Right Channel");
@@ -684,7 +709,8 @@ int setup_options()
 	if(fft_signal_source == RIGHT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_data_to_display), (gpointer)RIGHT);
+			GTK_SIGNAL_FUNC (set_fft_data_to_display), 
+			    GINT_TO_POINTER(RIGHT));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Left+Right (L+R)");
@@ -692,7 +718,8 @@ int setup_options()
 	if(fft_signal_source == LEFT_PLUS_RIGHT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_data_to_display), (gpointer)LEFT_PLUS_RIGHT);
+			GTK_SIGNAL_FUNC (set_fft_data_to_display), 
+			    GINT_TO_POINTER(LEFT_PLUS_RIGHT));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"Left-Right (L-R)");
@@ -700,7 +727,8 @@ int setup_options()
 	if(fft_signal_source == LEFT_MINUS_RIGHT)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_data_to_display), (gpointer)LEFT_MINUS_RIGHT);
+			GTK_SIGNAL_FUNC (set_fft_data_to_display), 
+			    GINT_TO_POINTER(LEFT_MINUS_RIGHT));
 
 	frame = gtk_frame_new("FFT Width");
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
@@ -717,7 +745,8 @@ int setup_options()
 	if(nsamp == 1024)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_1024);
+			GTK_SIGNAL_FUNC (set_fft_size), 
+			    GINT_TO_POINTER(S_1024));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"2048");
@@ -725,7 +754,8 @@ int setup_options()
 	if(nsamp == 2048)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_2048);
+			GTK_SIGNAL_FUNC (set_fft_size), 
+			    GINT_TO_POINTER(S_2048));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"4096");
@@ -733,7 +763,8 @@ int setup_options()
 	if(nsamp == 4096)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_4096);
+			GTK_SIGNAL_FUNC (set_fft_size), 
+			    GINT_TO_POINTER(S_4096));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"8192");
@@ -741,7 +772,8 @@ int setup_options()
 	if(nsamp == 8192)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_8192);
+			GTK_SIGNAL_FUNC (set_fft_size), 
+			    GINT_TO_POINTER(S_8192));
 
 	group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	button = gtk_radio_button_new_with_label(group,"16384");
@@ -749,7 +781,8 @@ int setup_options()
 	if(nsamp == 16384)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_16384);
+			GTK_SIGNAL_FUNC (set_fft_size), 
+			    GINT_TO_POINTER(S_16384));
 
 	/*    group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
 	 *    button = gtk_radio_button_new_with_label(group,"32768");
@@ -757,7 +790,7 @@ int setup_options()
 	 *    if(nsamp == 32768)
 	 *	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	 *    gtk_signal_connect (GTK_OBJECT (button), "toggled",
-	 *	    GTK_SIGNAL_FUNC (set_fft_size), (gpointer)S_32768);
+	 *	    GTK_SIGNAL_FUNC (set_fft_size), GINT_TO_POINTER(S_32768);
 	 */
 
 	gtk_widget_show_all(hbox);
@@ -787,7 +820,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)TAPE_SCROLL);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(TAPE_SCROLL));
 
 	label = gtk_label_new("Lag in Milliseconds");
 	gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,0);
@@ -800,7 +834,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (lag_adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)LAG);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(LAG));
 
 	label = gtk_label_new("Noise Floor");
 	gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,0);
@@ -812,7 +847,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)NOISE_FLOOR);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(NOISE_FLOOR));
 
 	label = gtk_label_new("Vertical Multiplier");
 	gtk_box_pack_start(GTK_BOX(vbox),label,TRUE,TRUE,0);
@@ -823,7 +859,8 @@ int setup_options()
 	gtk_range_set_update_policy(GTK_RANGE (scale),
 			GTK_UPDATE_CONTINUOUS);
 	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			GTK_SIGNAL_FUNC (slider_changed), (gpointer)SENSITIVITY);
+			GTK_SIGNAL_FUNC (slider_changed), 
+			    GINT_TO_POINTER(SENSITIVITY));
 
 	frame = gtk_frame_new("Buffer Latency Monitor");
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 5);
@@ -841,9 +878,11 @@ int setup_options()
 	buffer_pixmap = gdk_pixmap_new(buffer_area->window,400,100,
 			gtk_widget_get_visual(buffer_area)->depth);
 	gtk_signal_connect( GTK_OBJECT(buffer_area),"configure_event",
-			(GtkSignalFunc)configure_event, (gpointer)BUFFER_AREA);
+			(GtkSignalFunc)configure_event, 
+			    GINT_TO_POINTER(BUFFER_AREA));
 	gtk_signal_connect( GTK_OBJECT(buffer_area),"expose_event",
-			(GtkSignalFunc)expose_event,(gpointer)BUFFER_AREA);
+			(GtkSignalFunc)expose_event,
+			    GINT_TO_POINTER(BUFFER_AREA));
 	gdk_window_set_back_pixmap(buffer_area->window,buffer_pixmap,0);
 
 
